@@ -3,7 +3,12 @@ import typing
 import pandas as pd
 import pydantic
 
-from retrack.nodes.base import BaseNode, InputConnectionModel, NodeKind
+from retrack.nodes.base import (
+    BaseNode,
+    InputConnectionModel,
+    NodeKind,
+    OptionalCastedToNoneStringType,
+)
 from retrack.utils import constants
 
 ################################################
@@ -12,7 +17,7 @@ from retrack.utils import constants
 
 
 class OutputMetadataModel(pydantic.BaseModel):
-    message: str = None
+    message: OptionalCastedToNoneStringType = None
 
 
 ################################################
@@ -34,7 +39,7 @@ class Output(BaseNode):
     def kind(self) -> NodeKind:
         return NodeKind.OUTPUT
 
-    def run(self, input_value: pd.Series) -> typing.Dict[str, pd.Series]:
+    async def run(self, input_value: pd.Series) -> typing.Dict[str, pd.Series]:
         return {
             constants.OUTPUT_REFERENCE_COLUMN: input_value,
             constants.OUTPUT_MESSAGE_REFERENCE_COLUMN: self.data.message,
